@@ -6,7 +6,6 @@ import json
 import shutil
 import subprocess
 from pathlib import Path
-from typing import Optional
 
 import click
 import pkg_resources
@@ -274,12 +273,13 @@ def init(project_dir_str: str) -> None:
     )
 
     if plan_type == "avo":
-        print("")  # Terminal newline
+        logger.info("")  # Terminal newline
         logger.info(avo_end_msg)
 
 
 @click.command()
 @click.option(
+    "-n",
     "--name",
     "plan_name",
     required=True,
@@ -310,12 +310,13 @@ def new(plan_name: str) -> None:
     with open(plan_yml_file, "w") as f:
         yaml.dump(doc, f)
 
-    print("")  # Terminal newline
-    logger.info(f"[SUCCESS] Created Reflekt tracking plan '{plan_name}'")
+    logger.info("")  # Terminal newline
+    logger.success(f"Created Reflekt tracking plan '{plan_name}'")
 
 
 @click.command()
 @click.option(
+    "-n",
     "--name",
     "plan_name",
     required=True,
@@ -364,12 +365,13 @@ def pull(plan_name: str, raw: bool, avo_branch: str) -> None:
 
         logger.info(f"Building Reflekt tracking plan '{plan_name}' at {plan_dir}")
         plan.build_reflekt(plan_dir)
-        print("")  # Terminal newline
-        logger.info(f"[SUCCESS] Built Reflekt tracking plan '{plan_name}'")
+        logger.info("")  # Terminal newline
+        logger.success(f"Built Reflekt tracking plan '{plan_name}'")
 
 
 @click.command()
 @click.option(
+    "-n",
     "--name",
     "plan_name",
     required=True,
@@ -401,65 +403,115 @@ def push(plan_name, dry) -> None:
         )
         click.echo(json.dumps(payload, indent=2))
     else:
-        print("")  # Terminal newline
+        logger.info("")  # Terminal newline
         logger.info(
             f"Syncing converted tracking plan '{plan_name}' to "
             f"{titleize(transformer.plan_type)}"
         )
         api.sync(plan_name, cdp_plan)
-        print("")  # Terminal newline
-        logger.info(
-            f"[SUCCESS] Synced Reflekt tracking plan '{plan_name}' to "
+        logger.info("")  # Terminal newline
+        logger.success(
+            f"Synced Reflekt tracking plan '{plan_name}' to "
             f"{titleize(transformer.plan_type)}"
         )
 
 
 @click.command()
 @click.option(
+    "-e",
+    "--event",
+    "events",
+    type=str,
+    multiple=True,
+    required=False,
+    help="Name of a single event to be tested (in kebab-case).",
+)
+@click.option(
+    "-n",
     "--name",
     "plan_name",
+    type=str,
     required=True,
-    help="Tracking plan name in CDP or Analytics Governance tool.",
+    help="Name of tracking plan to be tested (in kebab-case).",
 )
-def test(plan_name: str) -> None:
+def test(plan_name, events) -> None:
     """Test tracking plan schema for naming, data types, and metadata."""
     plan_dir = ReflektProject().project_dir / "tracking-plans" / plan_name
     logger.info(f"Testing Reflekt tracking plan '{plan_name}'")
 
-    # Initialize ReflektLoader() always runs checks. Simple, but inelegant.
-    ReflektLoader(plan_dir=plan_dir, plan_name=plan_name)
+    # Initialize ReflektLoader() always runs checks. Simple, not elegant.
+    ReflektLoader(plan_dir=plan_dir, plan_name=plan_name, events=events)
 
     # If no errors are thrown, passed tests
     logger.info("")
-    logger.info(f"[PASSED] No errors detected in Reflekt tracking plan '{plan_name}'")
+    logger.success("Testing completed. No errors detected")
 
 
 @click.option(
-    "--name",
-    "plan_name",
-    required=True,
-    help="Tracking plan name in your Reflekt project.",
+    "--tag",
+    "force_tag",
+    is_flag=True,
+    required=False,
+    help="The git tag Reflekt should add after templating. Tag format = 'v<semantic_version>__reflekt_<project_name>_<cdp>'",  # noqa: E501
 )
 @click.option(
-    "--schema",
-    "schema",
+    "--commit",
+    "force_commit",
+    is_flag=True,
     required=False,
-    help=(
-        "Schema Reflekt will search when looking for raw event tables that match "
-        "tracking plan."
-    ),
+    help="The git commit Reflekt should add after templating. Commit format = 'build: reflekt_<project_name>_<cdp>/models/<schema_or_alias>/'",  # noqa: E501
+)
+@click.option(
+    "--skip-git",
+    "skip_git",
+    is_flag=True,
+    required=False,
+    help="Skip prompts at the end of templating to create Git commit and tag.",
 )
 @click.option(
     "--force-version",
     "force_version",
+    type=str,
     required=False,
     help="Force Reflekt to template the dbt package with a specified semantic version.",
 )
+@click.option(
+    "-s",
+    "--schema",
+    "schema",
+    type=str,
+    required=True,
+    help=(
+        "Schema Reflekt will search to look for raw event tables that match "
+        "tracking plan events."
+    ),
+)
+@click.option(
+    "-e",
+    "--event",
+    "events",
+    type=str,
+    multiple=True,
+    required=False,
+    help="Name of a single event to be tested (in kebab-case).",
+)
+@click.option(
+    "-n",
+    "--name",
+    "plan_name",
+    type=str,
+    required=True,
+    help="Tracking plan name in your Reflekt project.",
+)
 @click.command()
 def dbt(
-    plan_name: str,
-    schema: Optional[str] = None,
-    force_version: Optional[str] = None,
+    plan_name,
+    events,
+    schema,
+    force_version=None,
+    skip_git=None,
+    force_commit=None,
+    force_tag=None,
 ) -> None:
     """Build dbt package with sources, models, and docs based on tracking plan."""
     project = ReflektProject()
@@ -470,13 +522,13 @@ def dbt(
     plan_type = str.lower(config.plan_type)
     plan_dir = project_dir / "tracking-plans" / plan_name
     pkg_name = f"reflekt_{project_name}_{cdp}"
-    dbt_pkg_dir = project_dir / "dbt-packages" / pkg_name
-    dbt_project_yml = dbt_pkg_dir / "dbt_project.yml"
-    blank_pkg_template = pkg_resources.resource_filename("reflekt", "templates/dbt/")
-    tmp_pkg_dir = project_dir / ".reflekt" / "tmp" / pkg_name
-    warehouse_type = config.warehouse_type
+    project_dir / "dbt-packages" / pkg_name
+    dbt_project_yml = project.project_dir / "dbt_project.yml"
+    # blank_pkg_template = pkg_resources.resource_filename("reflekt", "templates/dbt/")
+    # tmp_pkg_dir = project_dir / ".reflekt" / "tmp" / pkg_name
+    config.warehouse_type
 
-    # Determine dbt pkg version
+    # Determine dbt pkg version to pass to ReflektTransformer
     if force_version:  # If user has forced version, use that
         try:
             version = parse_version(force_version)
@@ -537,140 +589,123 @@ def dbt(
             if not overwrite:
                 raise click.Abort()
 
-            print("")  # Newline in terminal
+            logger.info("")  # Terminal newline
             version = existing_version
 
-    # Setup temporary dbt pkg
-    if dbt_pkg_dir.exists():
-        # If dbt pk exists, use it as template
-        shutil.rmtree(tmp_pkg_dir)
-        shutil.copytree(dbt_pkg_dir, str(tmp_pkg_dir))
-    else:
-        if tmp_pkg_dir.exists():  # ensure tmp dir is empty
-            shutil.rmtree(tmp_pkg_dir)
-        # If dbt pkg doesn't exist, use blank template
-        shutil.copytree(blank_pkg_template, str(tmp_pkg_dir))
+    # # TODO: move this logic. Setup temporary dbt pkg
+    # if dbt_pkg_dir.exists():
+    #     # If dbt pk exists, use it as template
+    #     if tmp_pkg_dir.exists():
+    #         shutil.rmtree(tmp_pkg_dir)
+    #     shutil.copytree(dbt_pkg_dir, str(tmp_pkg_dir))
+    # else:
+    #     if tmp_pkg_dir.exists():  # ensure tmp dir is empty
+    #         shutil.rmtree(tmp_pkg_dir)
+    #     # If dbt pkg doesn't exist, use blank template
+    #     shutil.copytree(blank_pkg_template, str(tmp_pkg_dir))
 
     # Load Reflekt plan from 'tracking-plans/'
     logger.info(f"Loading Reflekt tracking plan {plan_name}")
-    loader = ReflektLoader(plan_dir=plan_dir, plan_name=plan_name, schema_name=schema)
+    loader = ReflektLoader(
+        plan_dir=plan_dir,
+        plan_name=plan_name,
+        schema_name=schema,
+        events=events,
+    )
     reflekt_plan = loader.plan
     logger.info(f"Loaded Reflekt tracking plan {plan_name}\n")
-    models_subfolder: Path = (
+
+    models_subfolder: str = (
         reflekt_plan.schema_alias
         if reflekt_plan.schema_alias is not None
         else reflekt_plan.schema
     )
-    models_subfolder_dir = tmp_pkg_dir / "models" / models_subfolder
-
-    if models_subfolder_dir.exists():
-        shutil.rmtree(models_subfolder_dir)
-
-    models_subfolder_dir.mkdir(parents=True, exist_ok=True)
-
-    logger.info(
-        f"Building Reflekt dbt package:"
-        f"\n        dbt package name: {pkg_name}"
-        f"\n        dbt package version: {version}"
-        f"\n        dbt package directory: {dbt_pkg_dir}"
-        f"\n        cdp: {cdp}"
-        f"\n        analytics governance tool: {plan_type}"
-        f"\n        tracking plan: {plan_name}"
-        f"\n        warehouse: {warehouse_type}"
-        f"\n        schema: {schema}"
-        f"\n        schema_alias: {reflekt_plan.schema_alias}"
-        f"\n        models subdirectory: models/{models_subfolder}\n"
-    )
-
-    # Update the version string in templated dbt_project.yml
-    with open(tmp_pkg_dir / "dbt_project.yml", "r") as f:
-        dbt_project_yml_str = f.read()
-
-    dbt_project_yml_str = dbt_project_yml_str.replace(
-        "0.1.0", str(version)  # Template always has version '0.1.0'
-    ).replace("reflekt_package_name", pkg_name)
-
-    with open(tmp_pkg_dir / "dbt_project.yml", "w") as f:
-        f.write(dbt_project_yml_str)
-
-    # Set dbt_pkg_name and plan_name in README.md
-    with open(tmp_pkg_dir / "README.md", "r") as f:
-        readme_str = f.read()
-
-    readme_str = readme_str.replace("_DBT_PKG_NAME_", pkg_name).replace(
-        "_PLAN_TOOL_", titleize(reflekt_plan.plan_type)
-    )
-
-    with open(tmp_pkg_dir / "README.md", "w") as f:
-        f.write(readme_str)
 
     transformer = ReflektTransformer(
         reflekt_plan=reflekt_plan,
-        dbt_package_name=pkg_name,
-        dbt_pkg_dir=dbt_pkg_dir,
-        tmp_pkg_dir=tmp_pkg_dir,
         models_subfolder=models_subfolder,
+        dbt_package_version=version,
     )
     transformer.build_dbt_package()
 
-    create_tag = click.confirm(
-        f"Would you like to create a Git commit and tag to easily reference this "
-        f"Reflekt dbt package {pkg_name} in your dbt project?",
-        default=False,
-    )
+    if not skip_git:
+        if force_commit:
+            commit_str = f"build: {pkg_name}/models/{models_subfolder}/"
+        else:
+            create_commit = click.confirm(
+                "Would you like Reflekt to create a Git commit after templating?",
+                default=False,
+            )
+            if create_commit:
+                commit_str = click.prompt(
+                    "Git commit message",
+                    type=str,
+                    default=f"build: {pkg_name}/models/{models_subfolder}/",
+                )
+            else:
+                commit_str = None
+
+        if force_tag:
+            tag_str = f"v{str(version)}__{pkg_name}"
+        else:
+            create_tag = click.confirm(
+                f"Would you like Reflekt to create a Git tag to easily reference "
+                f"dbt package {pkg_name} in your dbt project?",
+                default=False,
+            )
+            if create_tag:
+                tag_str = click.prompt(
+                    "Git tag",
+                    type=str,
+                    default=f"v{str(version)}__{pkg_name}",
+                )
+            else:
+                tag_str = None
 
-    if create_tag:
-        commit_msg = click.prompt(
-            "Git commit message will be",
-            type=str,
-            default=f"build: {pkg_name}",
-        )
-        tag = click.prompt(
-            "Git tag will be",
-            type=str,
-            default=f"v{str(version)}__{pkg_name}",
-        )
         git_executable = shutil.which("git")
         rel_pkg_path = f"dbt-packages/{pkg_name}"
 
-        if plan_type == "avo":
-            rel_avo_json_path = ".reflekt/avo/avo.json"
+        if commit_str is not None:
+            if plan_type == "avo":
+                rel_avo_json_path = ".reflekt/avo/avo.json"
+                subprocess.call(
+                    args=[
+                        git_executable,
+                        "add",
+                        rel_pkg_path,
+                        rel_avo_json_path,
+                    ],
+                    cwd=project_dir,
+                )
+            else:
+                subprocess.call(
+                    args=[
+                        git_executable,
+                        "add",
+                        rel_pkg_path,
+                    ],
+                    cwd=project_dir,
+                )
+
             subprocess.call(
                 args=[
                     git_executable,
-                    "add",
-                    rel_pkg_path,
-                    rel_avo_json_path,
-                ],
-                cwd=project_dir,
-            )
-        else:
-            subprocess.call(
-                args=[
-                    git_executable,
-                    "add",
-                    rel_pkg_path,
+                    "commit",
+                    "-m",
+                    commit_str,
                 ],
                 cwd=project_dir,
             )
 
-        subprocess.call(
-            args=[
-                git_executable,
-                "commit",
-                "-m",
-                commit_msg,
-            ],
-            cwd=project_dir,
-        )
-        subprocess.call(
-            args=[
-                git_executable,
-                "tag",
-                tag,
-            ],
-            cwd=project_dir,
-        )
+        if tag_str is not None:
+            subprocess.call(
+                args=[
+                    git_executable,
+                    "tag",
+                    tag_str,
+                ],
+                cwd=project_dir,
+            )
 
 
 # Add CLI commands to CLI group
@@ -689,15 +724,24 @@ if __name__ == "__main__":
     # new(["--project-dir", "test-plan"])
     # pull(["--name", "my-plan"])
     # push(["--name", "my-plan"])
-    # test(["--name", "my-plan"])
+    # test(
+    #     [
+    #         "--name",
+    #         "my-plan",
+    #         "-e",
+    #         "cart-viewed",
+    #         "-e",
+    #         "product-added",
+    #     ]
+    # )
     dbt(
         [
             "--name",
-            "surfline-web-test",
-            "--schema",
-            "surfline",
-            "--force-version",
-            "0.1.0",
+            "my-plan",
+            # "--schema",
+            # "my_app_web",
+            # "--force-version",
+            # "0.1.0",
         ]
     )
     # pull(["--name", "tracking-plan-example"])
